@@ -12,9 +12,8 @@
 #include <QDesktopServices>
 #include <QDir>
 #include <QFileInfo>
-#include <QFontDatabase>
-#include <QGuiApplication>
 #include <QMimeDatabase>
+#include <QQmlApplicationEngine>
 #include <QQuickView>
 #include <QStandardPaths>
 #include <QStyle>
@@ -27,7 +26,6 @@
 #include <KColorSchemeManager>
 #include <KCrash>
 #include <KFileItem>
-#include <KFileMetaData/Properties>
 #include <KLocalizedString>
 #include <KWindowSystem>
 
@@ -35,9 +33,10 @@
 
 #include "audiosettings.h"
 #include "generalsettings.h"
-#include "global.h"
+#include "pathutils.h"
 #include "haruna-version.h"
 #include "informationsettings.h"
+#include "miscutils.h"
 #include "mousesettings.h"
 #include "playbacksettings.h"
 #include "playlistsettings.h"
@@ -104,11 +103,10 @@ Application::Application()
     setupWorkerThread();
     setupAboutData();
     setupCommandLineParser();
-    setupQmlSettingsTypes();
 
     KCrash::initialize();
 
-    connect(Global::instance(), &Global::error, this, &Application::error);
+    connect(PathUtils::instance(), &PathUtils::error, MiscUtils::instance(), &MiscUtils::error);
 }
 
 Application::~Application()
@@ -195,112 +193,11 @@ void Application::setupCommandLineParser()
     }
 }
 
-void Application::setupQmlSettingsTypes()
-{
-    qmlRegisterSingletonInstance("org.kde.haruna.settings", 1, 0, "AudioSettings", AudioSettings::self());
-    qmlRegisterSingletonInstance("org.kde.haruna.settings", 1, 0, "GeneralSettings", GeneralSettings::self());
-    qmlRegisterSingletonInstance("org.kde.haruna.settings", 1, 0, "InformationSettings", InformationSettings::self());
-    qmlRegisterSingletonInstance("org.kde.haruna.settings", 1, 0, "MouseSettings", MouseSettings::self());
-    qmlRegisterSingletonInstance("org.kde.haruna.settings", 1, 0, "PlaybackSettings", PlaybackSettings::self());
-    qmlRegisterSingletonInstance("org.kde.haruna.settings", 1, 0, "PlaylistSettings", PlaylistSettings::self());
-    qmlRegisterSingletonInstance("org.kde.haruna.settings", 1, 0, "SubtitlesSettings", SubtitlesSettings::self());
-    qmlRegisterSingletonInstance("org.kde.haruna.settings", 1, 0, "VideoSettings", VideoSettings::self());
-}
-
-bool Application::urlExists(const QUrl &url)
-{
-    return pathExists(url.toLocalFile());
-}
-
-bool Application::pathExists(const QString &path)
-{
-    QFileInfo fileInfo(path);
-    if (fileInfo.exists()) {
-        return true;
-    }
-    return false;
-}
-
-QUrl Application::configFilePath()
-{
-    auto file = Global::instance()->appConfigFilePath();
-    if (pathExists(file)) {
-        return pathToUrl(file);
-    }
-    return QUrl();
-}
-
-QUrl Application::ccConfigFilePath()
-{
-    auto file = Global::instance()->appConfigFilePath(Global::ConfigFile::CustomCommands);
-    if (pathExists(file)) {
-        return pathToUrl(file);
-    }
-    return QUrl();
-}
-
-QUrl Application::configFolderPath()
-{
-    auto folder = Global::instance()->appConfigDirPath();
-    if (pathExists(folder)) {
-        return pathToUrl(folder);
-    }
-    return QUrl();
-}
-
-QUrl Application::pathToUrl(const QString &path)
-{
-    auto url = QUrl::fromUserInput(path);
-    if (!url.isValid()) {
-        return QUrl();
-    }
-    return url;
-}
-
-bool Application::configFolderExists()
-{
-    QFileInfo fi(Global::instance()->appConfigDirPath());
-    return fi.exists();
-}
-
 QString Application::version()
 {
     return QString::fromStdString(HARUNA_VERSION_STRING);
 }
 
-QUrl Application::parentUrl(const QString &path)
-{
-    QUrl url(path);
-    if (!url.isValid()) {
-        return QUrl(QStandardPaths::writableLocation(QStandardPaths::MoviesLocation));
-    }
-    QFileInfo fileInfo;
-    if (url.isLocalFile()) {
-        fileInfo.setFile(url.toLocalFile());
-    } else {
-        fileInfo.setFile(url.toString());
-    }
-    QUrl parentFolderUrl(fileInfo.absolutePath());
-    parentFolderUrl.setScheme(u"file"_s);
-
-    return parentFolderUrl;
-}
-
-QString Application::formatTime(const double time)
-{
-    int totalNumberOfSeconds = static_cast<int>(time);
-    int seconds = totalNumberOfSeconds % 60;
-    int minutes = (totalNumberOfSeconds / 60) % 60;
-    int hours = (totalNumberOfSeconds / 60 / 60);
-
-    QString hoursString = u"%1"_s.arg(hours, 2, 10, QLatin1Char('0'));
-    QString minutesString = u"%1"_s.arg(minutes, 2, 10, QLatin1Char('0'));
-    QString secondsString = u"%1"_s.arg(seconds, 2, 10, QLatin1Char('0'));
-    QString timeString = u"%1:%2:%3"_s.arg(hoursString, minutesString, secondsString);
-
-    return timeString;
-}
-
 QUrl Application::url(int key)
 {
     if (m_urls.contains(key)) {
@@ -315,21 +212,6 @@ void Application::addUrl(int key, const QString &value)
     m_urls.insert(key, QUrl::fromUserInput(value, QDir::currentPath()));
 }
 
-QString Application::getFileContent(const QString &file)
-{
-    QFile f(file);
-    f.open(QIODevice::ReadOnly);
-    QString content = QString::fromUtf8(f.readAll());
-    f.close();
-    return content;
-}
-
-QString Application::mimeType(QUrl url)
-{
-    KFileItem fileItem(url, KFileItem::NormalMimeTypeDetermination);
-    return fileItem.mimetype();
-}
-
 void Application::handleSecondayInstanceMessage(const QByteArray &message, const QString activationToken)
 {
     auto msgString = QString::fromStdString(message.data());
@@ -380,11 +262,6 @@ void Application::activateColorScheme(const QString &name)
     m_schemes->activateScheme(m_schemes->indexForScheme(name));
 }
 
-QStringList Application::getFonts()
-{
-    return QFontDatabase::families();
-}
-
 int Application::frameworksVersionMinor()
 {
     return KCONFIG_VERSION_MINOR;
@@ -395,11 +272,6 @@ int Application::qtMajorVersion()
     return QT_VERSION_MAJOR;
 }
 
-QString Application::platformName()
-{
-    return QGuiApplication::platformName();
-}
-
 void Application::raiseWindow()
 {
     QObject *rootObject = m_qmlEngine->rootObjects().constFirst();
@@ -414,9 +286,4 @@ void Application::raiseWindow()
     }
 }
 
-bool Application::isPlatformWayland()
-{
-    return KWindowSystem::isPlatformWayland();
-}
-
 #include "moc_application.cpp"
