@@ -8,13 +8,16 @@
 #define APPLICATION_H
 
 #include <QObject>
-#include <QQmlApplicationEngine>
 #include <QQmlPropertyMap>
+#include <QtQml/qqmlregistration.h>
 
 #include <KAboutData>
 
 class QAbstractItemModel;
 class QApplication;
+class QJSEngine;
+class QQmlApplicationEngine;
+class QQmlEngine;
 class QQuickWindow;
 class KActionCollection;
 class KConfigDialog;
@@ -48,30 +51,16 @@ public:
     bool actionsEnabled();
     void setActionsEnabled(bool enable);
 
-    Q_INVOKABLE bool urlExists(const QUrl &url);
-    Q_INVOKABLE bool pathExists(const QString &url);
-    Q_INVOKABLE QUrl configFilePath();
-    Q_INVOKABLE QUrl ccConfigFilePath();
-    Q_INVOKABLE QUrl configFolderPath();
-    Q_INVOKABLE QUrl pathToUrl(const QString &path);
-    Q_INVOKABLE bool configFolderExists();
-    Q_INVOKABLE QUrl parentUrl(const QString &path);
     Q_INVOKABLE QUrl url(int key);
     Q_INVOKABLE void addUrl(int key, const QString &value);
-    Q_INVOKABLE QString getFileContent(const QString &file);
     Q_INVOKABLE QStringList availableGuiStyles();
     Q_INVOKABLE void setGuiStyle(const QString &style);
     Q_INVOKABLE void activateColorScheme(const QString &name);
-    Q_INVOKABLE QStringList getFonts();
     Q_INVOKABLE int frameworksVersionMinor();
     Q_INVOKABLE int qtMajorVersion();
-    Q_INVOKABLE QString platformName();
     Q_INVOKABLE void raiseWindow();
-    Q_INVOKABLE bool isPlatformWayland();
 
     static QString version();
-    Q_INVOKABLE static QString formatTime(const double time);
-    Q_INVOKABLE static QString mimeType(QUrl url);
 
     void handleSecondayInstanceMessage(const QByteArray &message, const QString activationToken);
     QCommandLineParser *parser() const;
@@ -82,7 +71,6 @@ public:
 Q_SIGNALS:
     void qmlApplicationMouseLeave();
     void qmlApplicationMouseEnter();
-    void error(const QString &message);
     void openUrl(const QUrl &url);
     void actionsEnabledChanged();
 
@@ -98,7 +86,6 @@ private:
     void setupWorkerThread();
     void setupAboutData();
     void setupCommandLineParser();
-    void setupQmlSettingsTypes();
     QAbstractItemModel *colorSchemesModel();
     QApplication *m_app{nullptr};
     KAboutData m_aboutData;
