@@ -12,13 +12,13 @@
 #include <KConfigGroup>
 #include <KLocalizedString>
 
-#include "global.h"
+#include "pathutils.h"
 
 using namespace Qt::StringLiterals;
 
 ActionsModel::ActionsModel(QObject *parent)
     : QAbstractListModel(parent)
-    , m_config(KSharedConfig::openConfig(Global::instance()->appConfigFilePath(Global::ConfigFile::Shortcuts)))
+    , m_config(KSharedConfig::openConfig(PathUtils::instance()->configFilePath(PathUtils::ConfigFile::Shortcuts)))
 {
     Action action;
     action.name = u"openActionsDialogAction"_s;
