@@ -15,12 +15,12 @@
 #include <KFileMetaData/ExtractorCollection>
 #include <KFileMetaData/SimpleExtractionResult>
 
-#include "application.h"
+#include "miscutils.h"
 #include "mpvitem.h"
 #include "mpvproperties.h"
 #include "playlistsettings.h"
 #include "videosettings.h"
-#include "worker.h"
+// #include "worker.h"
 
 using namespace Qt::StringLiterals;
 
@@ -28,22 +28,22 @@ MediaPlayer2Player::MediaPlayer2Player(QObject *parent)
     : QDBusAbstractAdaptor(parent)
     , m_mpv{static_cast<MpvItem *>(parent)}
 {
-    connect(m_mpv, &MpvItem::fileLoaded, this, [=]() {
-        if (m_mpv->currentUrl().isLocalFile()) {
-            QString mimeType = Application::mimeType(m_mpv->currentUrl());
-            if (mimeType.startsWith(u"audio"_s)) {
-                Q_EMIT requestMprisThumbnail(m_mpv->currentUrl().toLocalFile(), 250);
-            }
-        }
-    });
+    // connect(m_mpv, &MpvItem::fileLoaded, this, [=]() {
+    //     if (m_mpv->currentUrl().isLocalFile()) {
+    //         QString mimeType = MiscUtils::mimeType(m_mpv->currentUrl());
+    //         if (mimeType.startsWith(u"audio"_s)) {
+    //             Q_EMIT requestMprisThumbnail(m_mpv->currentUrl().toLocalFile(), 250);
+    //         }
+    //     }
+    // });
 
-    connect(this, &MediaPlayer2Player::requestMprisThumbnail, Worker::instance(), &Worker::mprisThumbnail);
+    // connect(this, &MediaPlayer2Player::requestMprisThumbnail, Worker::instance(), &Worker::mprisThumbnail);
 
-    connect(Worker::instance(), &Worker::mprisThumbnailSuccess, this, [=](const QImage &image) {
-        m_image = image;
-        propertiesChanged(u"Metadata"_s, Metadata());
-        Q_EMIT metadataChanged();
-    });
+    // connect(Worker::instance(), &Worker::mprisThumbnailSuccess, this, [=](const QImage &image) {
+    //     m_image = image;
+    //     propertiesChanged(u"Metadata"_s, Metadata());
+    //     Q_EMIT metadataChanged();
+    // });
 
     connect(m_mpv, &MpvItem::mediaTitleChanged, this, [=]() {
         auto title = m_mpv->mediaTitle();
@@ -56,7 +56,7 @@ MediaPlayer2Player::MediaPlayer2Player(QObject *parent)
     });
 
     connect(m_mpv, &MpvItem::durationChanged, this, [=]() {
-        m_metadata.insert(u"mpris:length"_s, m_mpv->duration() * 1000 * 1000);
+        m_metadata.insert(u"mpris:length"_s, static_cast<qint64>(m_mpv->duration() * 1000 * 1000));
         propertiesChanged(u"Metadata"_s, m_metadata);
     });
 
@@ -92,7 +92,7 @@ void MediaPlayer2Player::propertiesChanged(const QString &property, const QVaria
 QVariantMap MediaPlayer2Player::Metadata()
 {
     auto url = m_mpv->currentUrl();
-    QString mimeType = Application::mimeType(url);
+    QString mimeType = MiscUtils::mimeType(url);
 
     m_metadata.insert(u"xesam:title"_s, m_mpv->mediaTitle());
     m_metadata.insert(u"mpris:trackid"_s, QVariant::fromValue<QDBusObjectPath>(QDBusObjectPath(u"/org/kde/haruna"_s)));
@@ -113,7 +113,7 @@ QString MediaPlayer2Player::getThumbnail(const QString &path)
         return QString();
     }
 
-    QString mimeType = Application::mimeType(url);
+    QString mimeType = MiscUtils::mimeType(url);
     KFileMetaData::ExtractorCollection exCol;
     QList<KFileMetaData::Extractor *> extractors = exCol.fetchExtractors(mimeType);
     KFileMetaData::SimpleExtractionResult result(path, mimeType, KFileMetaData::ExtractionResult::ExtractImageData);
